@@ -25,7 +25,6 @@
 #include <KPluginFactory>
 #include <QStringList>
 #include <QRegularExpression>
-#include <QDebug>
 
 #include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
 using namespace KSieveUi;
@@ -53,7 +52,7 @@ QString AutoCreateScriptUtil::createList(const QString &str, QChar separator, bo
     }
 }
 
-QString AutoCreateScriptUtil::quoteStr(QString str, bool protectSlash)
+QString AutoCreateScriptUtil::quoteStr(const QString &str, bool protectSlash)
 {
     QString st = str;
     if (protectSlash) {
@@ -101,6 +100,7 @@ QStringList AutoCreateScriptUtil::createListFromString(QString str)
     }
     lst = str.split(QStringLiteral(", "));
     QStringList resultLst;
+    resultLst.reserve(lst.count());
     for (QString s : qAsConst(lst)) {
         s.remove(QLatin1Char('"'));
         resultLst << s.trimmed();
@@ -214,9 +214,9 @@ QString AutoCreateScriptUtil::generateConditionComment(const QString &comment)
 {
     QString strComment;
     if (!comment.trimmed().isEmpty()) {
-        const QStringList commentList = comment.split(QLatin1Char('\n'));
+        const QVector<QStringRef> commentList = comment.splitRef(QLatin1Char('\n'));
 
-        for (const QString &str : commentList) {
+        for (const QStringRef &str : commentList) {
             if (str.isEmpty()) {
                 strComment += QLatin1Char('\n');
             } else {
