@@ -61,8 +61,9 @@ public:
 
 protected:
     SieveImapAccountSettings sieveImapAccountSettings() const;
+    QStringList listOfIncludeFile() const;
     QStringList sieveCapabilities() const;
-    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
+    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget = nullptr;
 
 Q_SIGNALS:
     void valueChanged();
