@@ -47,6 +47,9 @@ public:
     QString currentscript() override;
     void setImportScript(const QString &) override;
 
+    void setListOfIncludeFile(const QStringList &listOfIncludeFile) override;
+    QStringList listOfIncludeFile() const override;
+
 Q_SIGNALS:
     void enableButtonOk(bool);
     void switchTextMode(const QString &script);
@@ -64,10 +67,11 @@ private Q_SLOTS:
 
 private:
     QStringList mCapabilities;
-    SieveScriptListBox *mSieveScript;
-    QStackedWidget *mStackWidget;
-    QSplitter *mSplitter;
-    SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning;
+    QStringList mListOfIncludeFile;
+    SieveScriptListBox *mSieveScript = nullptr;
+    QStackedWidget *mStackWidget = nullptr;
+    QSplitter *mSplitter = nullptr;
+    SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning = nullptr;
 };
 }
 
