@@ -100,6 +100,7 @@ public:
     bool isTextEditor() const;
     SieveEditorTabWidget *tabWidget() const;
 
+    void setListOfIncludeFile(const QStringList &listOfIncludeFile);
 Q_SIGNALS:
     void enableButtonOk(bool);
     void switchToGraphicalMode();
@@ -121,22 +122,23 @@ private:
     bool loadFromFile(const QString &filename);
     QString mOriginalScript;
     QStringList mSieveCapabilities;
-    SieveTextEdit *mTextEdit;
-    KPIMTextEdit::PlainTextEditorWidget *mDebugTextEdit;
-    KPIMTextEdit::PlainTextEditFindBar *mFindBar;
-    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget;
-    SieveInfoWidget *mSieveInfo;
-    QSplitter *mMainSplitter;
-    QSplitter *mExtraSplitter;
-    QSplitter *mTemplateSplitter;
-    SieveEditorWarning *mSieveEditorWarning;
-    SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning;
-    SieveEditorTabWidget *mTabWidget;
-    KPIMTextEdit::TextGoToLineWidget *mGoToLine;
-    KPIMTextEdit::SlideContainer *mGotoLineSliderContainer;
-    KPIMTextEdit::SlideContainer *mSliderContainer;
-    SieveTemplateWidget *mSieveTemplateWidget;
-    QWidget *mEditorWidget;
+    QStringList mListOfIncludeFile;
+    SieveTextEdit *mTextEdit = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *mDebugTextEdit = nullptr;
+    KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
+    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+    SieveInfoWidget *mSieveInfo = nullptr;
+    QSplitter *mMainSplitter = nullptr;
+    QSplitter *mExtraSplitter = nullptr;
+    QSplitter *mTemplateSplitter = nullptr;
+    SieveEditorWarning *mSieveEditorWarning = nullptr;
+    SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning = nullptr;
+    SieveEditorTabWidget *mTabWidget = nullptr;
+    KPIMTextEdit::TextGoToLineWidget *mGoToLine = nullptr;
+    KPIMTextEdit::SlideContainer *mGotoLineSliderContainer = nullptr;
+    KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
+    SieveTemplateWidget *mSieveTemplateWidget = nullptr;
+    QWidget *mEditorWidget = nullptr;
 };
 }
 
