@@ -54,6 +54,7 @@ public:
 
     void setSieveCapabilities(const QStringList &capabilities);
     void setSieveImapAccountSettings(const SieveImapAccountSettings &sieveImapAccountSettings);
+    void setListOfIncludeFile(const QStringList &listOfIncludeFile);
 
     void addFailedMessage(const QString &err);
     void addOkMessage(const QString &msg);
@@ -129,20 +130,19 @@ private:
     void changeMode(EditorMode mode);
     void addMessageEntry(const QString &errorMsg, const QColor &color);
     QString mOriginalScript;
-    SieveEditorTextModeWidget *mTextModeWidget;
-    SieveEditorGraphicalModeWidget *mGraphicalModeWidget;
-    QStackedWidget *mStackedWidget;
-    QLineEdit *mScriptName;
-    QAction *mCheckSyntax;
-    QAction *mSwitchMode;
-    QAction *mCreateRulesGraphically;
-    QAction *mSaveAs;
-    QAction *mShareScript;
-#if !defined(NDEBUG)
-    QAction *mGenerateXml;
-#endif
-    EditorMode mMode;
-    bool mModified;
+    SieveEditorTextModeWidget *mTextModeWidget = nullptr;
+    SieveEditorGraphicalModeWidget *mGraphicalModeWidget = nullptr;
+    QStackedWidget *mStackedWidget = nullptr;
+    QLineEdit *mScriptName = nullptr;
+    QAction *mCheckSyntax = nullptr;
+    QAction *mSwitchMode = nullptr;
+    QAction *mCreateRulesGraphically = nullptr;
+    QAction *mSaveAs = nullptr;
+    QAction *mShareScript = nullptr;
+    QAction *mGenerateXml = nullptr;
+    EditorMode mMode = EditorMode::TextMode;
+    bool mModified = false;
+    bool mDebug = false;
 };
 }
 
