@@ -28,16 +28,15 @@
 #include "findbar/findbarwebengineview.h"
 
 using namespace KSieveUi;
-namespace
-{
+namespace {
 qreal zoomBy()
 {
     return 20;
 }
 }
 SieveEditorHelpHtmlWidget::SieveEditorHelpHtmlWidget(QWidget *parent)
-    : QWidget(parent),
-      mZoomFactor(100)
+    : QWidget(parent)
+    , mZoomFactor(100)
 {
     QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
@@ -45,6 +44,7 @@ SieveEditorHelpHtmlWidget::SieveEditorHelpHtmlWidget(QWidget *parent)
     mProgressIndicator->setObjectName(QStringLiteral("progressindicator"));
     connect(mProgressIndicator, &SieveEditorLoadProgressIndicator::pixmapChanged, this, &SieveEditorHelpHtmlWidget::slotPixmapChanged);
     connect(mProgressIndicator, &SieveEditorLoadProgressIndicator::loadFinished, this, &SieveEditorHelpHtmlWidget::slotLoadFinished);
+
     mWebView = new SieveEditorWebEngineView(this);
     mWebView->setObjectName(QStringLiteral("webview"));
     connect(mWebView, &SieveEditorWebEngineView::titleChanged, this, &SieveEditorHelpHtmlWidget::slotTitleChanged);
@@ -64,7 +64,6 @@ SieveEditorHelpHtmlWidget::SieveEditorHelpHtmlWidget(QWidget *parent)
 
 SieveEditorHelpHtmlWidget::~SieveEditorHelpHtmlWidget()
 {
-
 }
 
 QString SieveEditorHelpHtmlWidget::title() const
